// Clamps for bed leveling, designed for my Anycubic Kossel delta printer.
// More on:
// http://homofaciens.de/technics-machines-3D-printer-Anycubic-Kossel_en.htm

pitch = 2.0; //mm os movement per turn
layer_height = 0.15;
first_layer_height = 0.35;
thread_radius = 5;
thread_depth = 0.5; //total radius = thread_radius + 2 * thread_depth
thread_backlash = 0.0;
nut_backlash = 0.6;
angle_width = 360 / (pitch / layer_height);
bolt_length = 23;

clamp_height = 20;
wall_thickness = 3;
thread_x = -6.5;
thread_y = 7;
hole_x = -5;
hole_y = -15;
hole_radius = 2.5;
hole_radius_2 = 4.5;

nut_radius = 12.5;
nut_thickness = 3;

$fn = 50;
//$fa = 30;


// Clamp
translate([0, 0, clamp_height * 0.5]){
  difference(){
    translate([17, 0, 0]){
      cylinder($fa = 12, $fs = 2, h = clamp_height, r1 = 33, r2 = 32, center = true);
    }
    translate([200, 0, 0]){
      cylinder($fa = 12, $fn = 200, $fs = 2, h = clamp_height + 1, r1 = 200, r2 = 200, center = true);
    }
    translate([thread_x, thread_y, wall_thickness]){
      cylinder($fa = 12, $fs = 2, h = clamp_height, r1 = nut_radius + 2.5, r2 = nut_radius + 2.5, center = true);
    }
    translate([hole_x, hole_y, 0]){
      cylinder($fa = 12, $fs = 2, h = clamp_height + 1, r1 = hole_radius, r2 = hole_radius, center = true);
    }
    translate([hole_x, hole_y, wall_thickness + 1.5]){
      cylinder($fa = 12, $fs = 2, h = clamp_height, r1 = hole_radius_2, r2 = hole_radius_2, center = true);
    }
  }
}

// Threaded bolt
translate([thread_x, thread_y, 0]){
  cylinder(r = thread_radius, h = first_layer_height);
  translate([0,0,first_layer_height]){
    for (i=[0:1:bolt_length / layer_height])	{
      alpha = -i * angle_width;
      translate([sin(alpha) * (thread_depth - thread_backlash), cos(alpha) * (thread_depth - thread_backlash), i * layer_height]){
        cylinder(r = thread_radius - thread_backlash, h = layer_height);
      }
    }
  }
}



// Nut
translate([thread_x, thread_y, 40]){
  difference(){
    cylinder(r = nut_radius, h = nut_thickness);
    for (i=[0:18:360]){
      translate([sin(i) * nut_radius, cos(i) * nut_radius, 0]){
        cylinder(r = 1, h = nut_thickness + 0.1);
      }
    }
    translate([0, 0, -layer_height]){
      for (i=[0:1:(nut_thickness + 2 * layer_height) / layer_height])	{
        alpha = -i * angle_width;
        translate([sin(alpha) * thread_depth, cos(alpha) * thread_depth, i * layer_height]){
          cylinder(r = thread_radius + nut_backlash, h = layer_height);
        }
      }
    }
  }
}
